@@ -20,7 +20,7 @@ class Processor(object):
             self.event = request["headers"]["X-GitHub-Event"]
             self.branch = request["payload"]["ref"].split("/")[-1]
         except Exception, ex:
-            print "ERROR:", "processor constructor", ex
+            print "ERROR: parse request", ex
             self.application.ioloop.add_timeout(self.application.interval, self.application.next)
         else:
             self.tasks = ["git checkout %s" % self.branch, "git pull origin %s" % self.branch, self.read_config]
@@ -34,8 +34,8 @@ class Processor(object):
         try:
             tasks = config[self.branch][self.event]
             assert isinstance(tasks, list)
-        except (KeyError, AssertionError), ex:
-            print "ERROR:", "read_config", ex
+        except (KeyError, AssertionError):
+            print "ERROR: reading config"
         else:
             self.tasks.extend(tasks)
 
@@ -43,10 +43,8 @@ class Processor(object):
         try:
             task = self.tasks.pop(0)
         except IndexError:
-            self.application.ioloop.add_timeout(self.application.interval, self.application.next)
+            self.success()
         else:
-            print "new_task", task
-
             if hasattr(task, "__call__"):
                 task()
                 self.application.ioloop.add_timeout(self.application.interval, self.next)
@@ -61,6 +59,9 @@ class Processor(object):
     def error(self, ex):
         self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
+    def success(self):
+        self.application.ioloop.add_timeout(self.application.interval, self.application.next)
+
     def wait(self):
         try:
             pid, sts = subprocess._eintr_retry_call(os.waitpid, self.process.pid, 0)
@@ -79,7 +80,6 @@ class Processor(object):
 
         return_code = self.process.returncode
 
-        print "wait", return_code
         if return_code is None:
             self.application.ioloop.add_timeout(self.application.interval, self.wait)
         elif return_code == 0:
@@ -105,11 +105,9 @@ class Application(tornado.web.Application):
         try:
             request = self.queue.pop(0)
         except IndexError:
-            print "No work"
             self.current = None
             self.ioloop.add_timeout(self.interval, self.next)
         else:
-            print "New task"
             self.current = Processor(self, request)
 
 
@@ -125,8 +123,7 @@ class Handler(tornado.web.RequestHandler):
                 "headers": self.request.headers,
                 "payload": json.loads(self.request.body)
             }
-        except ValueError, ex:
-            print "ERROR:", ex
+        except ValueError:
             raise tornado.web.HTTPError(400)
         else:
             self.application.queue.append(request)
\ No newline at end of file
